==> jc-1.4.0.tar.gz: java/lang/Character__24Subset.c <==
// public class java.lang.Character$Subset

// class file dependencies
// @dep_class 416e61a7a7e51f54 java_lang_Character
// @dep_class 5a3b83efc151abe9 java_lang_Character__24Subset
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class a0a8fafccf4b2db9 java_lang_System
// @dep_class 4d1cebae0bdda058 java_lang_VMSystem

// header file dependencies
// @dep_header java_lang_Character
// @dep_header java_lang_Character__24Subset
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_System
// @dep_header java_lang_VMSystem

#include "jc_defs.h"

#include "java/lang/Character.h"
#include "java/lang/Character__24Subset.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/System.h"
#include "java/lang/VMSystem.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private final java.lang.String name
static _jc_field _jc_java_lang_Character__24Subset$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_java_lang_Character__24Subset$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_lang_Character__24Subset$object, refs[-1].java_lang_Character__24Subset.name),
};

// Fields
static _jc_field *const _jc_java_lang_Character__24Subset$fields[] = {
	&_jc_java_lang_Character__24Subset$field_info$name
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>(java.lang.String)
//

static _jc_linenum _jc_java_lang_Character__24Subset$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_java_lang_Character__24Subset$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_lang_Character__24Subset$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_java_lang_Character__24Subset$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_java_lang_Character__24Subset$type,
	.param_types=		&_jc_java_lang_Character__24Subset$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_Character__24Subset$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_java_lang_Character__24Subset$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_java_lang_Character__24Subset$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_Character__24Subset, _init$c31b894660454d13);

void
_jc_java_lang_Character__24Subset$method$_init$c31b894660454d13(_jc_env *const env, _jc_java_lang_Character__24Subset$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_java_lang_Character__24Subset$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	r1 = param0;
	_JC_EXPLICIT_NULL_CHECK(env, r1);
	_JC_LINE_NUMBER(93);				// 0
	_JC_REF_FIELD(env, r0, java_lang_Character__24Subset, name) = r1;
	_JC_LINE_NUMBER(94);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final boolean equals(java.lang.Object)
//

static _jc_linenum _jc_java_lang_Character__24Subset$linenum_table$equals$8a15e0625571c581[];

static const unsigned char _jc_java_lang_Character__24Subset$param_ptypes$equals$8a15e0625571c581[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_java_lang_Character__24Subset$param_types$equals$8a15e0625571c581[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_lang_Character__24Subset$method_info$equals$8a15e0625571c581 = {
	.name=			"equals",
	.signature=		"(Ljava/lang/Object;)Z",
	.class=			&_jc_java_lang_Character__24Subset$type,
	.param_types=		&_jc_java_lang_Character__24Subset$param_types$equals$8a15e0625571c581,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_java_lang_Character__24Subset$param_ptypes$equals$8a15e0625571c581,
	.signature_hash=	_JC_JLONG(0x8a15e0625571c581),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_Character__24Subset$method$equals$8a15e0625571c581,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_lang_Character__24Subset$vtable, java_lang_Character__24Subset.equals$8a15e0625571c581) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_Character__24Subset$linenum_table$equals$8a15e0625571c581
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_Character__24Subset, equals$8a15e0625571c581);

jboolean
_jc_java_lang_Character__24Subset$method$equals$8a15e0625571c581(_jc_env *const env, _jc_java_lang_Character__24Subset$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_java_lang_Character__24Subset$object *r0;
	struct _jc_java_lang_Object$object *r1;
	jboolean z0;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(106);				// 0
	z0 = 0;
	if (r1 != r0)
		goto label0;
	z0 = 1;

label0:
	return z0;
}

//
// public final int hashCode()
//

static _jc_linenum _jc_java_lang_Character__24Subset$linenum_table$hashCode$53152098849316df[];

static const unsigned char _jc_java_lang_Character__24Subset$param_ptypes$hashCode$53152098849316df[] = { 
_JC_TYPE_INT };

_jc_method _jc_java_lang_Character__24Subset$method_info$hashCode$53152098849316df = {
	.name=			"hashCode",
	.signature=		"()I",
	.class=			&_jc_java_lang_Character__24Subset$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_java_lang_Character__24Subset$param_ptypes$hashCode$53152098849316df,
	.signature_hash=	_JC_JLONG(0x53152098849316df),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_Character__24Subset$method$hashCode$53152098849316df,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_lang_Character__24Subset$vtable, java_lang_Character__24Subset.hashCode$53152098849316df) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_Character__24Subset$linenum_table$hashCode$53152098849316df
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_Character__24Subset, hashCode$53152098849316df);

jint
_jc_java_lang_Character__24Subset$method$hashCode$53152098849316df(_jc_env *const env, _jc_java_lang_Character__24Subset$object *this)
{
	jint i1;
	struct _jc_java_lang_Character__24Subset$object *r0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_ACTIVE_USE(env, java_lang_System);
	i1 = _JC_INVOKE_STATIC(env, java_lang_VMSystem, identityHashCode$08e9f770468404df, 0, r0);
	_JC_LINE_NUMBER(117);				// 0
	return i1;
}

//
// public final java.lang.String toString()
//

static _jc_linenum _jc_java_lang_Character__24Subset$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_java_lang_Character__24Subset$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_lang_Character__24Subset$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_lang_Character__24Subset$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_lang_Character__24Subset$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_Character__24Subset$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_lang_Character__24Subset$vtable, java_lang_Character__24Subset.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_Character__24Subset$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_Character__24Subset, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_java_lang_Character__24Subset$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_java_lang_Character__24Subset$object *this)
{
	struct _jc_java_lang_Character__24Subset$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(127);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_lang_Character__24Subset, name);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_Character__24Subset$methods[] = {
	&_jc_java_lang_Character__24Subset$method_info$_init$c31b894660454d13,
	&_jc_java_lang_Character__24Subset$method_info$equals$8a15e0625571c581,
	&_jc_java_lang_Character__24Subset$method_info$hashCode$53152098849316df,
	&_jc_java_lang_Character__24Subset$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_Character__24Subset$instanceof_hash_bucket_105[] = {
	&_jc_java_lang_Character__24Subset$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_Character__24Subset$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_Character__24Subset$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[105]=	_jc_java_lang_Character__24Subset$instanceof_hash_bucket_105,
	[113]=	_jc_java_lang_Character__24Subset$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_Character__24Subset$class_depends[] = {
	{ "java/lang/Character",	_JC_JLONG(0x416e61a7a7e51f54) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/System",	_JC_JLONG(0xa0a8fafccf4b2db9) },
	{ "java/lang/VMSystem",	_JC_JLONG(0x4d1cebae0bdda058) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_Character__24Subset$vtype _jc_java_lang_Character__24Subset$type = {
    .type= {
	.name=			"java/lang/Character$Subset",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0x5a3b83efc151abe9),
		.source_file=		"Character.java",
		.instance_size=		sizeof(_jc_java_lang_Character__24Subset$refs) + sizeof(_jc_java_lang_Character__24Subset$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_lang_Character__24Subset$fields) / sizeof(*_jc_java_lang_Character__24Subset$fields),
		.fields=		_jc_java_lang_Character__24Subset$fields,
		.num_methods=		sizeof(_jc_java_lang_Character__24Subset$methods) / sizeof(*_jc_java_lang_Character__24Subset$methods),
		.methods=		_jc_java_lang_Character__24Subset$methods,
		.instanceof_hash_table=	_jc_java_lang_Character__24Subset$instanceof_hash_table,
		.outer_class=		&_jc_java_lang_Character$type,
		.num_class_depends=		sizeof(_jc_java_lang_Character__24Subset$class_depends) / sizeof(*_jc_java_lang_Character__24Subset$class_depends),
		.class_depends=		_jc_java_lang_Character__24Subset$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=			// overridden
		&_jc_java_lang_Character__24Subset$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=			// overridden
		&_jc_java_lang_Character__24Subset$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_lang_Character__24Subset$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_Character__24Subset= {
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Character__24Subset$method$equals$8a15e0625571c581,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Character__24Subset$method$hashCode$53152098849316df,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Character__24Subset$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: java/lang/Character__24Subset.c <==
// public class java.lang.Character$Subset

// class file dependencies
// @dep_class 416e61a7a7e51f54 java_lang_Character
// @dep_class 5a3b83efc151abe9 java_lang_Character__24Subset
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 53cc8e2333795f04 java_lang_System
// @dep_class 4d1cebae0bdda058 java_lang_VMSystem

// header file dependencies
// @dep_header java_lang_Character
// @dep_header java_lang_Character__24Subset
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_System
// @dep_header java_lang_VMSystem

#include "jc_defs.h"

#include "java/lang/Character.h"
#include "java/lang/Character__24Subset.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/System.h"
#include "java/lang/VMSystem.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private final java.lang.String name
static _jc_field _jc_java_lang_Character__24Subset$field_info$name = {
	.name=		"name",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_java_lang_Character__24Subset$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PRIVATE|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_lang_Character__24Subset$object, refs[-1].java_lang_Character__24Subset.name),
};

// Fields
static _jc_field *const _jc_java_lang_Character__24Subset$fields[] = {
	&_jc_java_lang_Character__24Subset$field_info$name
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// protected void <init>(java.lang.String)
//

static _jc_linenum _jc_java_lang_Character__24Subset$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_java_lang_Character__24Subset$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_lang_Character__24Subset$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_java_lang_Character__24Subset$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_java_lang_Character__24Subset$type,
	.param_types=		&_jc_java_lang_Character__24Subset$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_lang_Character__24Subset$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_java_lang_Character__24Subset$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_java_lang_Character__24Subset$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_Character__24Subset, _init$c31b894660454d13);

void _JC_JCNI_ATTR
_jc_java_lang_Character__24Subset$method$_init$c31b894660454d13(_jc_env *const env, _jc_java_lang_Character__24Subset$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_java_lang_Character__24Subset$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	r1 = param0;
	_JC_EXPLICIT_NULL_CHECK(env, r1);
	_JC_LINE_NUMBER(93);				// 0
	_JC_REF_FIELD(env, r0, java_lang_Character__24Subset, name) = r1;
	_JC_LINE_NUMBER(94);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final boolean equals(java.lang.Object)
//

static _jc_linenum _jc_java_lang_Character__24Subset$linenum_table$equals$8a15e0625571c581[];

static const unsigned char _jc_java_lang_Character__24Subset$param_ptypes$equals$8a15e0625571c581[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_BOOLEAN };

static _jc_type *const _jc_java_lang_Character__24Subset$param_types$equals$8a15e0625571c581[] = {
	&_jc_java_lang_Object$type
};

_jc_method _jc_java_lang_Character__24Subset$method_info$equals$8a15e0625571c581 = {
	.name=			"equals",
	.signature=		"(Ljava/lang/Object;)Z",
	.class=			&_jc_java_lang_Character__24Subset$type,
	.param_types=		&_jc_java_lang_Character__24Subset$param_types$equals$8a15e0625571c581,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_java_lang_Character__24Subset$param_ptypes$equals$8a15e0625571c581,
	.signature_hash=	_JC_JLONG(0x8a15e0625571c581),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_Character__24Subset$method$equals$8a15e0625571c581,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_lang_Character__24Subset$vtable, java_lang_Character__24Subset.equals$8a15e0625571c581) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_Character__24Subset$linenum_table$equals$8a15e0625571c581
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_Character__24Subset, equals$8a15e0625571c581);

jboolean _JC_JCNI_ATTR
_jc_java_lang_Character__24Subset$method$equals$8a15e0625571c581(_jc_env *const env, _jc_java_lang_Character__24Subset$object *this, _jc_java_lang_Object$object *param0)
{
	struct _jc_java_lang_Character__24Subset$object *r0;
	struct _jc_java_lang_Object$object *r1;
	jboolean z0;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(106);				// 0
	z0 = 0;
	if (r1 != r0)
		goto label0;
	z0 = 1;

label0:
	return z0;
}

//
// public final int hashCode()
//

static _jc_linenum _jc_java_lang_Character__24Subset$linenum_table$hashCode$53152098849316df[];

static const unsigned char _jc_java_lang_Character__24Subset$param_ptypes$hashCode$53152098849316df[] = { 
_JC_TYPE_INT };

_jc_method _jc_java_lang_Character__24Subset$method_info$hashCode$53152098849316df = {
	.name=			"hashCode",
	.signature=		"()I",
	.class=			&_jc_java_lang_Character__24Subset$type,
	.return_type=		&_jc_int$prim$type,
	.param_ptypes=		&_jc_java_lang_Character__24Subset$param_ptypes$hashCode$53152098849316df,
	.signature_hash=	_JC_JLONG(0x53152098849316df),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_Character__24Subset$method$hashCode$53152098849316df,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_lang_Character__24Subset$vtable, java_lang_Character__24Subset.hashCode$53152098849316df) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_Character__24Subset$linenum_table$hashCode$53152098849316df
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_Character__24Subset, hashCode$53152098849316df);

jint _JC_JCNI_ATTR
_jc_java_lang_Character__24Subset$method$hashCode$53152098849316df(_jc_env *const env, _jc_java_lang_Character__24Subset$object *this)
{
	jint i1;
	struct _jc_java_lang_Character__24Subset$object *r0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_ACTIVE_USE(env, java_lang_System);
	i1 = _JC_INVOKE_STATIC(env, java_lang_VMSystem, identityHashCode$08e9f770468404df, 0, r0);
	_JC_LINE_NUMBER(117);				// 0
	return i1;
}

//
// public final java.lang.String toString()
//

static _jc_linenum _jc_java_lang_Character__24Subset$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_java_lang_Character__24Subset$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_lang_Character__24Subset$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_java_lang_Character__24Subset$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_java_lang_Character__24Subset$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_lang_Character__24Subset$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_lang_Character__24Subset$vtable, java_lang_Character__24Subset.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_lang_Character__24Subset$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_lang_Character__24Subset, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_java_lang_Character__24Subset$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_java_lang_Character__24Subset$object *this)
{
	struct _jc_java_lang_Character__24Subset$object *r0;
	struct _jc_java_lang_String$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(127);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_lang_Character__24Subset, name);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_lang_Character__24Subset$methods[] = {
	&_jc_java_lang_Character__24Subset$method_info$_init$c31b894660454d13,
	&_jc_java_lang_Character__24Subset$method_info$equals$8a15e0625571c581,
	&_jc_java_lang_Character__24Subset$method_info$hashCode$53152098849316df,
	&_jc_java_lang_Character__24Subset$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_lang_Character__24Subset$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_java_lang_Character__24Subset$instanceof_hash_bucket_105[] = {
	&_jc_java_lang_Character__24Subset$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_lang_Character__24Subset$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[101]=	_jc_java_lang_Character__24Subset$instanceof_hash_bucket_101,
	[105]=	_jc_java_lang_Character__24Subset$instanceof_hash_bucket_105
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_lang_Character__24Subset$class_depends[] = {
	{ "java/lang/Character",	_JC_JLONG(0x416e61a7a7e51f54) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/System",	_JC_JLONG(0x53cc8e2333795f04) },
	{ "java/lang/VMSystem",	_JC_JLONG(0x4d1cebae0bdda058) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_lang_Character__24Subset$vtype _jc_java_lang_Character__24Subset$type = {
    .type= {
	.name=			"java/lang/Character$Subset",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0x5a3b83efc151abe9),
		.source_file=		"Character.java",
		.instance_size=		sizeof(_jc_java_lang_Character__24Subset$refs) + sizeof(_jc_java_lang_Character__24Subset$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_lang_Character__24Subset$fields) / sizeof(*_jc_java_lang_Character__24Subset$fields),
		.fields=		_jc_java_lang_Character__24Subset$fields,
		.num_methods=		sizeof(_jc_java_lang_Character__24Subset$methods) / sizeof(*_jc_java_lang_Character__24Subset$methods),
		.methods=		_jc_java_lang_Character__24Subset$methods,
		.instanceof_hash_table=	_jc_java_lang_Character__24Subset$instanceof_hash_table,
		.outer_class=		&_jc_java_lang_Character$type,
		.num_class_depends=		sizeof(_jc_java_lang_Character__24Subset$class_depends) / sizeof(*_jc_java_lang_Character__24Subset$class_depends),
		.class_depends=		_jc_java_lang_Character__24Subset$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=			// overridden
		&_jc_java_lang_Character__24Subset$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=			// overridden
		&_jc_java_lang_Character__24Subset$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_java_lang_Character__24Subset$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_lang_Character__24Subset= {
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Character__24Subset$method$equals$8a15e0625571c581,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Character__24Subset$method$hashCode$53152098849316df,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Character__24Subset$method$toString$7ea43b33b80a3070,
	},
    }
};
